@@ -29,7 +29,7 @@ use zune_core::colorspace::ColorSpace;
 use zune_core::log::{debug, error, warn};
 
 use crate::bitstream::BitStream;
-use crate::components::{ComponentID, SampleRatios};
+use crate::components::SampleRatios;
 use crate::decoder::{JpegDecoder, MAX_COMPONENTS};
 use crate::errors::DecodeErrors;
 use crate::headers::parse_sos;
@@ -98,7 +98,6 @@ impl<T: ZByteReaderTrait> JpegDecoder<T> {
 
         mcu_width *= 64;
 
-
         for i in 0..self.input_colorspace.num_components() {
             let comp = &self.components[i];
             let len = mcu_width * comp.vertical_sample * comp.horizontal_sample * mcu_height;
@@ -106,14 +105,20 @@ impl<T: ZByteReaderTrait> JpegDecoder<T> {
             block[i] = vec![0; len];
         }
 
-        let mut stream = BitStream::new_progressive(
-            self.succ_low,
-            self.spec_start,
-            self.spec_end
-        );
+        let mut stream = BitStream::new_progressive(self.succ_low, self.spec_start, self.spec_end);
 
         // there are multiple scans in the stream, this should resolve the first scan
-        self.parse_entropy_coded_data(&mut stream, &mut block)?;
+        let result = self.parse_entropy_coded_data(&mut stream, &mut block);
+
+        if result.is_err() {
+            return if self.options.strict_mode() {
+                Err(result.err().unwrap())
+            } else {
+                error!("{}", result.err().unwrap());
+                // Go process it and return as much as we can, exiting here
+                return self.finish_progressive_decoding(&block, pixels);
+            };
+        }
 
         // extract marker
         let mut marker = stream
@@ -138,7 +143,18 @@ impl<T: ZByteReaderTrait> JpegDecoder<T> {
                         self.spec_end
                     );
                     // after every SOS, marker, parse data for that scan.
-                    self.parse_entropy_coded_data(&mut stream, &mut block)?;
+                    let result = self.parse_entropy_coded_data(&mut stream, &mut block);
+
+                    // Do not error out too fast, allows the decoder to continue as much as possible
+                    // even after errors
+                    if result.is_err() {
+                        return if self.options.strict_mode() {
+                            Err(result.err().unwrap())
+                        } else {
+                            error!("{}", result.err().unwrap());
+                            break 'eoi;
+                        };
+                    }
                     // extract marker, might either indicate end of image or we continue
                     // scanning(hence the continue statement to determine).
                     match get_marker(&mut self.stream, &mut stream) {
@@ -181,11 +197,15 @@ impl<T: ZByteReaderTrait> JpegDecoder<T> {
                         return Err(e);
                     }
                     error!("{}", e);
+                    // If we can't get the marker, just break away
+                    // allows us to decode some corrupt images
+                    // e.g https://github.com/etemesi254/zune-image/issues/294
+                    break 'eoi;
                 }
             }
         }
 
-        self.finish_progressive_decoding(&block, mcu_width, pixels)
+        self.finish_progressive_decoding(&block, pixels)
     }
 
     /// Reset progressive parameters
@@ -229,12 +249,11 @@ impl<T: ZByteReaderTrait> JpegDecoder<T> {
 
             let (mcu_width, mcu_height);
 
-            if self.components[k].component_id == ComponentID::Y
-                && (self.components[k].vertical_sample != 1
-                    || self.components[k].horizontal_sample != 1)
+            if self.components[k].vertical_sample != 1
+                || self.components[k].horizontal_sample != 1
                 || !self.is_interleaved
             {
-                // For Y channel  or non interleaved scans ,
+                // For non interleaved scans
                 // mcu's is the image dimensions divided by 8
                 mcu_width = self.info.width.div_ceil(8) as usize;
                 mcu_height = self.info.height.div_ceil(8) as usize;
@@ -430,15 +449,26 @@ impl<T: ZByteReaderTrait> JpegDecoder<T> {
             // https://github.com/etemesi254/zune-image/issues/261
             let _start = self.stream.position()?;
             // skip bytes until we find marker
-            let marker = get_marker(&mut self.stream, stream)?;
-            let _end = self.stream.position()?;
-            stream.marker = Some(marker);
-            // NB some warnings may be false positives.
-            warn!(
-                "{} Extraneous bytes before marker {:?}",
-                _end - _start,
-                marker
-            );
+            let marker = get_marker(&mut self.stream, stream);
+
+            // In some images, the RST marker on the last section may not be available
+            // as it is maybe stopped by an EOI marker, see in the case of https://github.com/etemesi254/zune-image/issues/292
+            // what happened was that we would go looking for the RST marker exhausting all the data
+            // in the image and this would return an error, so for now
+            // translate it to a warning, but return the image decoded up
+            // until that point
+            if let Ok(marker) = marker {
+                let _end = self.stream.position()?;
+                stream.marker = Some(marker);
+                // NB some warnings may be false positives.
+                warn!(
+                    "{} Extraneous bytes before marker {:?}",
+                    _end - _start,
+                    marker
+                );
+            } else {
+                warn!("RST marker was not found, where expected, image may be garbled")
+            }
         }
         if self.todo == 0 {
             self.handle_rst(stream)?
@@ -448,7 +478,7 @@ impl<T: ZByteReaderTrait> JpegDecoder<T> {
     #[allow(clippy::too_many_lines)]
     #[allow(clippy::needless_range_loop, clippy::cast_sign_loss)]
     fn finish_progressive_decoding(
-        &mut self, block: &[Vec<i16>; MAX_COMPONENTS], _mcu_width: usize, pixels: &mut [u8]
+        &mut self, block: &[Vec<i16>; MAX_COMPONENTS], pixels: &mut [u8]
     ) -> Result<(), DecodeErrors> {
         // This function is complicated because we need to replicate
         // the function in mcu.rs
@@ -483,7 +513,6 @@ impl<T: ZByteReaderTrait> JpegDecoder<T> {
         let width = usize::from(self.info.width);
         let padded_width = calculate_padded_width(width, self.sub_sample_ratio);
 
-        //let mut pixels = vec![0; capacity * out_colorspace_components];
         let mut upsampler_scratch_space = vec![0; upsampler_scratch_size];
         let mut tmp = [0_i32; DCT_BLOCK];
 
@@ -664,4 +693,4 @@ where
 //         decoder.decode().unwrap();
 //
 //     }
-// }
\ No newline at end of file
+// }
